﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Media.Imaging;
using System.Windows.Media;
using System.IO;
using Infragistics.Controls.Charts;

namespace ToImage
{

   public class PointXY
   {
      public double X { get; set; }
      public double Y { get; set; }

      public PointXY()
      {
         this.X = 0;
         this.Y = 0;
      }
      public PointXY(double x, double y)
      {
         this.X = x;
         this.Y = y;
      }
   }

   public class ViewModel
   {
      public XamDataChart ManualChart { get; set; }
      public List<PointXY> Data { get; set; }

      public ViewModel()
      {
         this.SetupData();
         this.SetupManualChart();
         
      }

      private void SetupData()
      {
         this.Data = new List<PointXY>();
         this.Data.Add(new PointXY(0, 0));
         this.Data.Add(new PointXY(1, 1));
         this.Data.Add(new PointXY(5, 1));
      }

      private void SetupManualChart()
      {
         this.ManualChart = new XamDataChart();

         this.ManualChart.Background = System.Windows.Media.Brushes.White;

         NumericXAxis xAxis = new NumericXAxis();
         xAxis.Name = "XAxis";
         xAxis.Interval = 1;
         xAxis.MinimumValue = -1;
         xAxis.MaximumValue = 6;
         xAxis.Title = "X Units";
         this.ManualChart.Axes.Add(xAxis);

         NumericYAxis yAxis = new NumericYAxis();
         yAxis.Name = "YAxis";
         yAxis.Interval = 1;
         yAxis.MinimumValue = -1;
         yAxis.MaximumValue = 2;
         yAxis.Title = "Y Units";
         this.ManualChart.Axes.Add(yAxis);

         ScatterLineSeries series = new ScatterLineSeries();
         series.XMemberPath = "X";
         series.YMemberPath = "Y";
         series.ItemsSource = Data;
         series.MarkerType = MarkerType.Square;
         series.XAxis = xAxis;
         series.YAxis = yAxis;
         this.ManualChart.Series.Add(series);

         int height = 600;
         int width = 800;
         this.ManualChart.Height = height;
         this.ManualChart.Width = width;
         this.ManualChart.RenderSize = new System.Windows.Size(width, height);

         this.ManualChart.UpdateLayout();
      }

      public void PrintChart(XamDataChart chart, String path)
      {
         int width = (int)chart.ActualWidth;
         int height = (int)chart.ActualHeight;

         RenderTargetBitmap bmp = new RenderTargetBitmap(width, height, 96, 96, PixelFormats.Pbgra32);
         bmp.Render(chart);

         PngBitmapEncoder png = new PngBitmapEncoder();
         png.Frames.Add(BitmapFrame.Create(bmp));


         using (Stream stm = File.Create(path))
         {
            png.Save(stm);
         }

         System.Diagnostics.Process.Start(path);
      }
   }
}
